﻿# Powershell script to check Last Logon Time for users older than 40 days in Active Directory. 
#The script than exports the report as a CSV file which is emailed to a list of users as needed.
# Author - Thomas Wilkop  
# info@ppe-it.de


PSSnapin Microsoft.Exchange.Management.Powershell.Admin -erroraction silentlyContinue  
Import-module activedirectory  

# Update to the required SMTP Server
$smtpServer = "smtp.example.local" 

# File used for storing and emailing over.
$file = "C:\ADInactiveUsers.csv" 

# Specify Users who will recieve the report
$user1 = "user1@example.local"
$user2 = "user2@example.local"

# Deletes any legacy files on that location
del $file

# Generates the inactive users list and exports them to the file with the required attributes
$IncactiveDate = (get-date).adddays(-40) #Count for Inactive days. I am using 40 can be changed to as needed.
$USERS = get-aduser -filter {lastlogondate -le $IncactiveDate} -Properties EmployeeId, lastlogondate |  select-object DistinguishedName, Enabled, GivenName, LastLogonDate,name, surname, userprincipalname, EmployeeId | export-csv $file -notypeinformation
Disable-ADAccount -filter {lastlogondate -le $IncactiveDate} -Properties EmployeeId, lastlogondate |  select-object DistinguishedName, Enabled, GivenName, LastLogonDate,name, surname, userprincipalname, EmployeeId


# Attaches the file attachement and sends the email to the users listed above
$att = new-object Net.Mail.Attachment($file)
$msg = new-object Net.Mail.MailMessage
$smtp = new-object Net.Mail.SmtpClient($smtpServer)
$msg.From = "it@example.local"
$msg.To.Add($user1)
$msg.To.Add($user2)
$msg.Subject = "Inactive AD Users over 40 days"
$msg.Body = "Attached are AD users older than 40 days"
$msg.Attachments.Add($att)
$smtp.Send($msg)
$att.Dispose()

